==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/msk_cluster/MskClusterBrokerNodeGroupInfo.java <==
package com.hashicorp.cdktf.providers.aws.msk_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.790Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.mskCluster.MskClusterBrokerNodeGroupInfo")
@software.amazon.jsii.Jsii.Proxy(MskClusterBrokerNodeGroupInfo.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MskClusterBrokerNodeGroupInfo extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#client_subnets MskCluster#client_subnets}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getClientSubnets();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#instance_type MskCluster#instance_type}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getInstanceType();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#security_groups MskCluster#security_groups}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getSecurityGroups();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#az_distribution MskCluster#az_distribution}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAzDistribution() {
        return null;
    }

    /**
     * connectivity_info block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/msk_cluster#connectivity_info MskCluster#connectivity_info}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo getConnectivityInfo() {
        return null;
    }

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#ebs_volume_size MskCluster#ebs_volume_size}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getEbsVolumeSize() {
        return null;
    }

    /**
     * storage_info block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/msk_cluster#storage_info MskCluster#storage_info}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo getStorageInfo() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MskClusterBrokerNodeGroupInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MskClusterBrokerNodeGroupInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MskClusterBrokerNodeGroupInfo> {
        java.util.List<java.lang.String> clientSubnets;
        java.lang.String instanceType;
        java.util.List<java.lang.String> securityGroups;
        java.lang.String azDistribution;
        com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo connectivityInfo;
        java.lang.Number ebsVolumeSize;
        com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo storageInfo;

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getClientSubnets}
         * @param clientSubnets Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#client_subnets MskCluster#client_subnets}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clientSubnets(java.util.List<java.lang.String> clientSubnets) {
            this.clientSubnets = clientSubnets;
            return this;
        }

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getInstanceType}
         * @param instanceType Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#instance_type MskCluster#instance_type}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder instanceType(java.lang.String instanceType) {
            this.instanceType = instanceType;
            return this;
        }

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getSecurityGroups}
         * @param securityGroups Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#security_groups MskCluster#security_groups}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder securityGroups(java.util.List<java.lang.String> securityGroups) {
            this.securityGroups = securityGroups;
            return this;
        }

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getAzDistribution}
         * @param azDistribution Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#az_distribution MskCluster#az_distribution}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder azDistribution(java.lang.String azDistribution) {
            this.azDistribution = azDistribution;
            return this;
        }

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getConnectivityInfo}
         * @param connectivityInfo connectivity_info block.
         *                         Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/msk_cluster#connectivity_info MskCluster#connectivity_info}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectivityInfo(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo connectivityInfo) {
            this.connectivityInfo = connectivityInfo;
            return this;
        }

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getEbsVolumeSize}
         * @param ebsVolumeSize Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster#ebs_volume_size MskCluster#ebs_volume_size}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ebsVolumeSize(java.lang.Number ebsVolumeSize) {
            this.ebsVolumeSize = ebsVolumeSize;
            return this;
        }

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getStorageInfo}
         * @param storageInfo storage_info block.
         *                    Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/msk_cluster#storage_info MskCluster#storage_info}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder storageInfo(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo storageInfo) {
            this.storageInfo = storageInfo;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MskClusterBrokerNodeGroupInfo}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MskClusterBrokerNodeGroupInfo build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MskClusterBrokerNodeGroupInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MskClusterBrokerNodeGroupInfo {
        private final java.util.List<java.lang.String> clientSubnets;
        private final java.lang.String instanceType;
        private final java.util.List<java.lang.String> securityGroups;
        private final java.lang.String azDistribution;
        private final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo connectivityInfo;
        private final java.lang.Number ebsVolumeSize;
        private final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo storageInfo;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.clientSubnets = software.amazon.jsii.Kernel.get(this, "clientSubnets", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.instanceType = software.amazon.jsii.Kernel.get(this, "instanceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.securityGroups = software.amazon.jsii.Kernel.get(this, "securityGroups", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.azDistribution = software.amazon.jsii.Kernel.get(this, "azDistribution", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.connectivityInfo = software.amazon.jsii.Kernel.get(this, "connectivityInfo", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo.class));
            this.ebsVolumeSize = software.amazon.jsii.Kernel.get(this, "ebsVolumeSize", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.storageInfo = software.amazon.jsii.Kernel.get(this, "storageInfo", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.clientSubnets = java.util.Objects.requireNonNull(builder.clientSubnets, "clientSubnets is required");
            this.instanceType = java.util.Objects.requireNonNull(builder.instanceType, "instanceType is required");
            this.securityGroups = java.util.Objects.requireNonNull(builder.securityGroups, "securityGroups is required");
            this.azDistribution = builder.azDistribution;
            this.connectivityInfo = builder.connectivityInfo;
            this.ebsVolumeSize = builder.ebsVolumeSize;
            this.storageInfo = builder.storageInfo;
        }

        @Override
        public final java.util.List<java.lang.String> getClientSubnets() {
            return this.clientSubnets;
        }

        @Override
        public final java.lang.String getInstanceType() {
            return this.instanceType;
        }

        @Override
        public final java.util.List<java.lang.String> getSecurityGroups() {
            return this.securityGroups;
        }

        @Override
        public final java.lang.String getAzDistribution() {
            return this.azDistribution;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo getConnectivityInfo() {
            return this.connectivityInfo;
        }

        @Override
        public final java.lang.Number getEbsVolumeSize() {
            return this.ebsVolumeSize;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo getStorageInfo() {
            return this.storageInfo;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("clientSubnets", om.valueToTree(this.getClientSubnets()));
            data.set("instanceType", om.valueToTree(this.getInstanceType()));
            data.set("securityGroups", om.valueToTree(this.getSecurityGroups()));
            if (this.getAzDistribution() != null) {
                data.set("azDistribution", om.valueToTree(this.getAzDistribution()));
            }
            if (this.getConnectivityInfo() != null) {
                data.set("connectivityInfo", om.valueToTree(this.getConnectivityInfo()));
            }
            if (this.getEbsVolumeSize() != null) {
                data.set("ebsVolumeSize", om.valueToTree(this.getEbsVolumeSize()));
            }
            if (this.getStorageInfo() != null) {
                data.set("storageInfo", om.valueToTree(this.getStorageInfo()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.mskCluster.MskClusterBrokerNodeGroupInfo"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MskClusterBrokerNodeGroupInfo.Jsii$Proxy that = (MskClusterBrokerNodeGroupInfo.Jsii$Proxy) o;

            if (!clientSubnets.equals(that.clientSubnets)) return false;
            if (!instanceType.equals(that.instanceType)) return false;
            if (!securityGroups.equals(that.securityGroups)) return false;
            if (this.azDistribution != null ? !this.azDistribution.equals(that.azDistribution) : that.azDistribution != null) return false;
            if (this.connectivityInfo != null ? !this.connectivityInfo.equals(that.connectivityInfo) : that.connectivityInfo != null) return false;
            if (this.ebsVolumeSize != null ? !this.ebsVolumeSize.equals(that.ebsVolumeSize) : that.ebsVolumeSize != null) return false;
            return this.storageInfo != null ? this.storageInfo.equals(that.storageInfo) : that.storageInfo == null;
        }

        @Override
        public final int hashCode() {
            int result = this.clientSubnets.hashCode();
            result = 31 * result + (this.instanceType.hashCode());
            result = 31 * result + (this.securityGroups.hashCode());
            result = 31 * result + (this.azDistribution != null ? this.azDistribution.hashCode() : 0);
            result = 31 * result + (this.connectivityInfo != null ? this.connectivityInfo.hashCode() : 0);
            result = 31 * result + (this.ebsVolumeSize != null ? this.ebsVolumeSize.hashCode() : 0);
            result = 31 * result + (this.storageInfo != null ? this.storageInfo.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/msk_cluster/MskClusterBrokerNodeGroupInfo.java <==
package com.hashicorp.cdktf.providers.aws.msk_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.803Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.mskCluster.MskClusterBrokerNodeGroupInfo")
@software.amazon.jsii.Jsii.Proxy(MskClusterBrokerNodeGroupInfo.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MskClusterBrokerNodeGroupInfo extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#client_subnets MskCluster#client_subnets}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getClientSubnets();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#instance_type MskCluster#instance_type}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getInstanceType();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#security_groups MskCluster#security_groups}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getSecurityGroups();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#az_distribution MskCluster#az_distribution}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAzDistribution() {
        return null;
    }

    /**
     * connectivity_info block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#connectivity_info MskCluster#connectivity_info}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo getConnectivityInfo() {
        return null;
    }

    /**
     * storage_info block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#storage_info MskCluster#storage_info}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo getStorageInfo() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MskClusterBrokerNodeGroupInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MskClusterBrokerNodeGroupInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MskClusterBrokerNodeGroupInfo> {
        java.util.List<java.lang.String> clientSubnets;
        java.lang.String instanceType;
        java.util.List<java.lang.String> securityGroups;
        java.lang.String azDistribution;
        com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo connectivityInfo;
        com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo storageInfo;

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getClientSubnets}
         * @param clientSubnets Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#client_subnets MskCluster#client_subnets}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder clientSubnets(java.util.List<java.lang.String> clientSubnets) {
            this.clientSubnets = clientSubnets;
            return this;
        }

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getInstanceType}
         * @param instanceType Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#instance_type MskCluster#instance_type}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder instanceType(java.lang.String instanceType) {
            this.instanceType = instanceType;
            return this;
        }

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getSecurityGroups}
         * @param securityGroups Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#security_groups MskCluster#security_groups}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder securityGroups(java.util.List<java.lang.String> securityGroups) {
            this.securityGroups = securityGroups;
            return this;
        }

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getAzDistribution}
         * @param azDistribution Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#az_distribution MskCluster#az_distribution}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder azDistribution(java.lang.String azDistribution) {
            this.azDistribution = azDistribution;
            return this;
        }

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getConnectivityInfo}
         * @param connectivityInfo connectivity_info block.
         *                         Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#connectivity_info MskCluster#connectivity_info}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder connectivityInfo(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo connectivityInfo) {
            this.connectivityInfo = connectivityInfo;
            return this;
        }

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfo#getStorageInfo}
         * @param storageInfo storage_info block.
         *                    Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#storage_info MskCluster#storage_info}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder storageInfo(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo storageInfo) {
            this.storageInfo = storageInfo;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MskClusterBrokerNodeGroupInfo}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MskClusterBrokerNodeGroupInfo build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MskClusterBrokerNodeGroupInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MskClusterBrokerNodeGroupInfo {
        private final java.util.List<java.lang.String> clientSubnets;
        private final java.lang.String instanceType;
        private final java.util.List<java.lang.String> securityGroups;
        private final java.lang.String azDistribution;
        private final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo connectivityInfo;
        private final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo storageInfo;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.clientSubnets = software.amazon.jsii.Kernel.get(this, "clientSubnets", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.instanceType = software.amazon.jsii.Kernel.get(this, "instanceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.securityGroups = software.amazon.jsii.Kernel.get(this, "securityGroups", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.azDistribution = software.amazon.jsii.Kernel.get(this, "azDistribution", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.connectivityInfo = software.amazon.jsii.Kernel.get(this, "connectivityInfo", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo.class));
            this.storageInfo = software.amazon.jsii.Kernel.get(this, "storageInfo", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.clientSubnets = java.util.Objects.requireNonNull(builder.clientSubnets, "clientSubnets is required");
            this.instanceType = java.util.Objects.requireNonNull(builder.instanceType, "instanceType is required");
            this.securityGroups = java.util.Objects.requireNonNull(builder.securityGroups, "securityGroups is required");
            this.azDistribution = builder.azDistribution;
            this.connectivityInfo = builder.connectivityInfo;
            this.storageInfo = builder.storageInfo;
        }

        @Override
        public final java.util.List<java.lang.String> getClientSubnets() {
            return this.clientSubnets;
        }

        @Override
        public final java.lang.String getInstanceType() {
            return this.instanceType;
        }

        @Override
        public final java.util.List<java.lang.String> getSecurityGroups() {
            return this.securityGroups;
        }

        @Override
        public final java.lang.String getAzDistribution() {
            return this.azDistribution;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoConnectivityInfo getConnectivityInfo() {
            return this.connectivityInfo;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfo getStorageInfo() {
            return this.storageInfo;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("clientSubnets", om.valueToTree(this.getClientSubnets()));
            data.set("instanceType", om.valueToTree(this.getInstanceType()));
            data.set("securityGroups", om.valueToTree(this.getSecurityGroups()));
            if (this.getAzDistribution() != null) {
                data.set("azDistribution", om.valueToTree(this.getAzDistribution()));
            }
            if (this.getConnectivityInfo() != null) {
                data.set("connectivityInfo", om.valueToTree(this.getConnectivityInfo()));
            }
            if (this.getStorageInfo() != null) {
                data.set("storageInfo", om.valueToTree(this.getStorageInfo()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.mskCluster.MskClusterBrokerNodeGroupInfo"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MskClusterBrokerNodeGroupInfo.Jsii$Proxy that = (MskClusterBrokerNodeGroupInfo.Jsii$Proxy) o;

            if (!clientSubnets.equals(that.clientSubnets)) return false;
            if (!instanceType.equals(that.instanceType)) return false;
            if (!securityGroups.equals(that.securityGroups)) return false;
            if (this.azDistribution != null ? !this.azDistribution.equals(that.azDistribution) : that.azDistribution != null) return false;
            if (this.connectivityInfo != null ? !this.connectivityInfo.equals(that.connectivityInfo) : that.connectivityInfo != null) return false;
            return this.storageInfo != null ? this.storageInfo.equals(that.storageInfo) : that.storageInfo == null;
        }

        @Override
        public final int hashCode() {
            int result = this.clientSubnets.hashCode();
            result = 31 * result + (this.instanceType.hashCode());
            result = 31 * result + (this.securityGroups.hashCode());
            result = 31 * result + (this.azDistribution != null ? this.azDistribution.hashCode() : 0);
            result = 31 * result + (this.connectivityInfo != null ? this.connectivityInfo.hashCode() : 0);
            result = 31 * result + (this.storageInfo != null ? this.storageInfo.hashCode() : 0);
            return result;
        }
    }
}
